@@ -42,7 +42,7 @@ def valid_hostnames(hostname_list):
     for entry in hostname_list:
         if len(entry) > 255:
             return False
-        allowed = re.compile("(?!-)[A-Z\d-]{1,63}(?<!-)$", re.IGNORECASE)
+        allowed = re.compile('(?!-)[A-Z\d-]{1,63}(?<!-)$', re.IGNORECASE)
         if not all(allowed.match(x) for x in entry.split(".")):
             return False
     return True
@@ -59,11 +59,11 @@ def is_readable(path=None):
     return False
 
 
-def is_writeable(path=None):
+def dedupe_list(seq):
     """
-    Test if the supplied filesystem path can be written to
-    :param path: A filesystem path
-    :return: True if the path is a file that can be written. Otherwise, False
+    Utility function to remove duplicates from a list
+    :param seq: The sequence (list) to deduplicate
+    :return: A list with original duplicates removed
     """
-    if os.path.isfile(path) and os.access(path, os.W_OK):
-        return True
+    seen = set()
+    return [x for x in seq if not (x in seen or seen.add(x))]
